pub struct Flowgraph { /* private fields */ }Trait Implementations
Sourceimpl Component for Flowgraph
impl Component for Flowgraph
Sourcetype Message = Msg
type Message = Msg
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcetype Properties = Props
type Properties = Props
The Component’s properties. Read more
Sourcefn rendered(&mut self, ctx: &Context<Self>, first_render: bool)
fn rendered(&mut self, ctx: &Context<Self>, first_render: bool)
The
rendered method is called after each time a Component is rendered but
before the browser updates the page. Read moreSourcefn update(&mut self, _ctx: &Context<Self>, msg: Self::Message) -> bool
fn update(&mut self, _ctx: &Context<Self>, msg: Self::Message) -> bool
Called when a new message is sent to the component via it’s scope. Read more
Sourcefn view(&self, _ctx: &Context<Self>) -> Html
fn view(&self, _ctx: &Context<Self>) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation. Read moreAuto Trait Implementations
impl Freeze for Flowgraph
impl RefUnwindSafe for Flowgraph
impl Send for Flowgraph
impl Sync for Flowgraph
impl Unpin for Flowgraph
impl UnwindSafe for Flowgraph